@@ -1,12 +1,15 @@
 import datetime
 import time
+import os
 from signal import signal, SIGINT
 
 from commands import logs_url, test_results
 from neoload_cli_lib import tools, rest_crud
 
+import sys
+import webbrowser
+
 __current_id = None
-__endpoint = "v2/test-results/"
 __count = 0
 
 __last_status = ""
@@ -25,7 +28,6 @@ def wait(results_id, exit_code_sla):
     __current_id = results_id
     signal(SIGINT, handler)
     header_status(results_id)
-    time.sleep(5)
     while display_status(results_id):
         time.sleep(20)
 
@@ -34,14 +36,18 @@ def wait(results_id, exit_code_sla):
 
 
 def header_status(results_id):
+    url = logs_url.get_url(results_id)
     print("Results of  : " + results_id)
-    print("Logs are available at " + logs_url.get_url(results_id))
+    print("Logs are available at " + url)
+    if sys.stdin.isatty() and os.getenv('NL_OPEN_BROWSER'):
+        time.sleep(1)
+        webbrowser.open_new_tab(url)
 
 
 # INIT, STARTING, RUNNING, TERMINATED
 def display_status(results_id):
     global __last_status
-    res = rest_crud.get('v2/test-results/' + results_id)
+    res = rest_crud.get(test_results.get_end_point(results_id))
     status = res.get('status')
 
     if __last_status != status:
@@ -56,7 +62,7 @@ def display_status(results_id):
 
 
 def display_statistics(results_id, json_summary):
-    res = rest_crud.get(__endpoint + results_id + '/statistics')
+    res = rest_crud.get(test_results.get_end_point(results_id, '/statistics'))
     time_cur = datetime.datetime.now() - datetime.datetime.fromtimestamp((json_summary['startDate'] + 1) / 1000)
     time_cur_format = format_delta(time_cur)
     lg_count = json_summary.get('lgCount') or '--'
@@ -81,6 +87,6 @@ def format_delta(delta):
 def stop(results_id, force: bool, quit_option=False):
     policy = 'TERMINATE' if force else 'GRACEFUL'
     if tools.confirm("Do you want stop the test" + results_id + " with " + policy.lower() + " policy ?", quit_option):
-        rest_crud.post(__endpoint + results_id + "/stop", {"stopPolicy": policy})
+        rest_crud.post(test_results.get_end_point(results_id, "/stop"), {"stopPolicy": policy})
         return True
     return False
