@@ -1,4 +1,5 @@
 import json
+import os
 import re
 import sys
 
@@ -9,15 +10,52 @@ from termcolor import cprint
 from neoload_cli_lib import rest_crud, user_data
 
 __regex_id = re.compile('[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}')
+__regex_mongodb_id = re.compile('[a-f\\d]{24}', re.IGNORECASE)
 
 __batch = False
 
 
+def __is_color_terminal():
+    if not sys.stdout.isatty():
+        return False
+    if os.getenv('COLORTERM'):
+        return True
+    if os.getenv('TERM_PROGRAM') in {'iTerm.app', 'Hyper', 'Apple_Terminal'}:
+        return True
+    if os.getenv('TERM') in {'screen-256', 'screen-256color', 'xterm-256', 'xterm-256color', 'color', 'cygwin'}:
+        return True
+    return False
+
+
+__is_color_term = __is_color_terminal()
+
+
+def is_color_terminal():
+    return __is_color_term
+
+
+def print_color(text, color=None, on_color=None, attrs=None, **kwargs):
+    if __is_color_term:
+        cprint(text, color, on_color, attrs, **kwargs)
+    else:
+        print(text)
+
+
 def set_batch(batch: bool):
     global __batch
     __batch = batch
 
 
+def is_batch():
+    return __batch
+
+
+def is_mongodb_id(chain: str):
+    if chain:
+        return __regex_mongodb_id.match(chain)
+    return False
+
+
 def is_id(chain: str):
     if chain:
         return __regex_id.match(chain)
@@ -53,7 +91,7 @@ def ls(name, is_id_, resolver):
     if name:
         get_id_and_print_json(get_named_or_id(name, is_id_, resolver))
     else:
-        print_json(rest_crud.get(endpoint))
+        print_json(rest_crud.get_with_pagination(endpoint))
 
 
 def delete(endpoint, id_data, kind):
@@ -74,7 +112,7 @@ def use(name, meta_key, resolver):
 
 
 def print_json(json_data):
-    print(json.dumps(json_data, indent=2))
+    print(json.dumps(json_data, indent=2, ensure_ascii=False))
 
 
 def get_id_and_print_json(json_data: json):
@@ -92,18 +130,26 @@ def is_integer(string):
         return False
 
 
-def get_id(name, resolver, is_an_id=None):
+def get_id(name, resolver, is_an_id=None, return_none=False):
     if is_an_id is None:
         is_an_id = is_id(name)
     if is_an_id or not name:
         return name
     else:
-        return resolver.resolve_name(name)
+        return resolver.resolve_name(name, return_none)
 
 
 def system_exit(exit_process, apply_exit_code=True):
     exit_code = exit_process['code']
     if exit_process['message'] != '':
-        cprint(exit_process['message'], 'green' if exit_code == 0 else 'red')
+        print_color(exit_process['message'], 'green' if exit_code == 0 else 'red')
     if apply_exit_code or exit_code > 1:
         sys.exit(exit_process['code'])
+
+
+def ssl_cert_to_verify(ssl_cert):
+    if not ssl_cert:
+        return True
+    if ssl_cert == 'False':
+        return False
+    return ssl_cert
